@@ -1,6 +1,8 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
+#opensshstatus v2.2-11
+
 import gobject, gtk
 import hildon
 from hildondesktop import StatusMenuItem
@@ -61,7 +63,7 @@ class opensshStatus(StatusMenuItem):
             self.parser.set('options', 'trackingEnabled', str(self.trackingEnabled))
             self.parser.set('options', 'stopTracking', str(self.stopTracking))
             self.parser.set('options', 'stopWhenIdle', str(self.stopWhenIdle))
-            self.parser.set('options', 'stopAfterMinutes', str(self.stopAfterMinutes) + " minutes")
+            self.parser.set('options', 'stopAfterMinutes', str(self.stopAfterMinutes))
             self.parser.set('options', 'confirmDisconnect', str(self.confirmDisconnect))
             self.parser.set('options', 'showRestartButton', str(self.showRestartButton))
             self.parser.set('options', 'showAllConnections', str(self.showAllConnections))
@@ -480,12 +482,15 @@ class opensshStatus(StatusMenuItem):
         self.sshRunning = int(getoutput("ps aux | grep -c /usr/sbin/sshd")) - 2
         
     def sshUsers(self):
-        self.sshConnected = int(getoutput("netstat -t | grep -c :ssh[[:space:]]*[0-9].*ESTABLISHED"))
+        try:
+            self.sshConnected = int(getoutput("netstat -t | grep -c :ssh[[:space:]]*[0-9].*ESTABLISHED"))
+        except:
+            self.sshConnected = 0
         
     def sshAllUsers(self):
-        self.sshConnected = int(getoutput("netstat -t | grep -c :ssh[[:space:]]*[0-9].*ESTABLISHED"))
+        self.sshUsers()
         sshNetstat = getoutput("netstat -t | grep :ssh.*ESTABLISHED").split("\n")
-        if sshNetstat[0] == "":
+        if "ESTABLISHED" not in sshNetstat[0]:
             sshNetstat = []
         
         countInWLAN = 0
@@ -669,7 +674,7 @@ class opensshStatus(StatusMenuItem):
         if wlanIP == "None":
             self.printInfo("No WLAN was detected.\nWifi PM is <b>not</b> kept off for 30 sec.", 7)
         else:
-            if  not int(getoutput("netstat -t | grep :ssh.*ESTABLISHED | grep -c " + wlanIP)):
+            if not int(getoutput("netstat -t | grep :ssh.*ESTABLISHED | grep -c " + wlanIP)):
                 self.printInfo("Wifi PM is kept off for 30 sec.\nGood time to connect...", 7)
                 system("sudo openssh-status.sh wifipmoff_once")
             elif int(getoutput("ps aux | grep -v grep  | grep -c /usr/sbin/osw-power-management")):
@@ -1071,7 +1076,7 @@ class opensshStatus(StatusMenuItem):
     def sshCountAll(self, dummy):
         self.sshUsers()
         sshNetstat = getoutput("netstat -t | grep :ssh.*ESTABLISHED").split("\n")
-        if sshNetstat[0] == "":
+        if "ESTABLISHED" not in sshNetstat[0]:
             sshNetstat = []
         
         countInWLAN = 0
